@@ -28,18 +28,18 @@ public:
     bool readable { false };
     bool writeable { false };
     bool executable { false };
+    QVariantMap customData;
 
     // time info
     qint64 lastRead { 0 };
     qint64 lastModifed { 0 };
     qint64 create { 0 };
 
-    QString displayType { "" };  // 文件类型
     QString highlightContent { "" };   // 存储文件的高亮内容
-    
+
     // 信息完整性标记
     bool infoCompleted { false };   // 标记详细信息是否已获取
-    
+
     // 线程安全
     mutable QMutex mutex;
 };
