@@ -961,7 +961,6 @@ bool FileUtils::containsCopyingFileUrl(const QUrl &url)
     return copyingUrl.contains(url);
 }
 
-// TODO: remove it!
 void FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType type, const QUrl &url)
 {
     if (!url.isValid())
@@ -972,6 +971,8 @@ void FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType type,
             return true;
         if (ProtocolUtils::isFTPFile(url))
             return true;
+        if (ProtocolUtils::isNFSFile(url))
+            return true;
 
         return false;
     };
@@ -983,7 +984,7 @@ void FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType type,
     if (!urlParent.isValid())
         return;
 
-    AbstractFileWatcherPointer watcher = WatcherFactory::create<AbstractFileWatcher>(DFMIO::DFMUtils::directParentUrl(url));
+    AbstractFileWatcherPointer watcher = WatcherFactory::create<AbstractFileWatcher>(urlParent);
     if (!watcher)
         return;
 
@@ -1001,122 +1002,6 @@ void FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType type,
         return;
     }
 }
-// fix 多线程排序时，该处的全局变量在compareByString函数中可能导致软件崩溃
-// QCollator sortCollator;
-class DCollator : public QCollator
-{
-public:
-    DCollator()
-        : QCollator()
-    {
-        setNumericMode(true);
-        setCaseSensitivity(Qt::CaseInsensitive);
-    }
-};
-
-bool FileUtils::isNumOrChar(const QChar ch)
-{
-    QChar normalized;
-    if (isFullWidthChar(ch, normalized))
-        return isNumOrChar(normalized);
-
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    return (ch >= 48 && ch <= 57) || (ch >= 65 && ch <= 90) || (ch >= 97 && ch <= 122);
-#else
-    auto chValue = ch.unicode();
-    return (chValue >= 48 && chValue <= 57) || (chValue >= 65 && chValue <= 90) || (chValue >= 97 && chValue <= 122);
-#endif
-}
-
-bool FileUtils::isNumber(const QChar ch)
-{
-    QChar number;
-    if (isFullWidthChar(ch, number))
-        return isNumber(number);
-
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    return (ch >= 48 && ch <= 57);
-#else
-    auto chValue = ch.unicode();
-    return (chValue >= 48 && chValue <= 57);
-#endif
-}
-
-bool FileUtils::isFullWidthChar(const QChar ch, QChar &normalized)
-{
-    // 全角字符的 Unicode 范围
-    ushort unicode = ch.unicode();
-
-    // 处理全角数字 (0xFF10-0xFF19)
-    if (unicode >= 0xFF10 && unicode <= 0xFF19) {
-        normalized = QChar(unicode - 0xFF10 + '0');
-        return true;
-    }
-
-    // 处理全角大写字母 (0xFF21-0xFF3A)
-    if (unicode >= 0xFF21 && unicode <= 0xFF3A) {
-        normalized = QChar(unicode - 0xFF21 + 'A');
-        return true;
-    }
-
-    // 处理全角小写字母 (0xFF41-0xFF5A)
-    if (unicode >= 0xFF41 && unicode <= 0xFF5A) {
-        normalized = QChar(unicode - 0xFF41 + 'a');
-        return true;
-    }
-
-    // 处理全角标点符号
-    static const QHash<ushort, QChar> punctuationMap {
-        { 0xFF01, '!' },   // ！
-        { 0xFF08, '(' },   // （
-        { 0xFF09, ')' },   // ）
-        { 0xFF0C, ',' },   // ，
-        { 0xFF1A, ':' },   // ：
-        { 0xFF1B, ';' },   // ；
-        { 0xFF1F, '?' },   // ？
-        { 0xFF3B, '[' },   // ［
-        { 0xFF3D, ']' },   // ］
-        { 0xFF5B, '{' },   // ｛
-        { 0xFF5D, '}' },   // ｝
-        { 0xFF0E, '.' },   // ．
-        { 0xFF0F, '/' },   // ／
-        { 0xFF3F, '_' },   // ＿
-        { 0xFF0D, '-' },   // －
-        { 0xFF1D, '=' },   // ＝
-        { 0xFF06, '&' },   // ＆
-        { 0xFF5C, '|' },   // ｜
-        { 0xFF1C, '<' },   // ＜
-        { 0xFF1E, '>' },   // ＞
-        { 0xFF02, '"' },   // ＂
-        { 0xFF07, '\'' },   // ＇
-        { 0xFF0B, '+' },   // ＋
-        { 0xFF03, '#' },   // ＃
-        { 0xFF04, '$' },   // ＄
-        { 0xFF05, '%' },   // ％
-        { 0xFF20, '@' },   // ＠
-        { 0xFF0A, '*' },   // ＊
-        { 0xFF3C, '\\' },   // ＼
-        { 0xFF5E, '~' }   // ～
-    };
-
-    auto it = punctuationMap.find(unicode);
-    if (it != punctuationMap.end()) {
-        normalized = it.value();
-        return true;
-    }
-
-    return false;
-}
-
-QString FileUtils::makeQString(const QString::const_iterator &it, uint unicode)
-{
-    if (it->isHighSurrogate()) {
-        QString str(QChar::highSurrogate(unicode));
-        str.append(QChar::lowSurrogate(unicode));
-        return str;
-    }
-    return *it;
-}
 
 QString FileUtils::symlinkTarget(const QUrl &url)
 {
@@ -1127,7 +1012,8 @@ QString FileUtils::symlinkTarget(const QUrl &url)
     return QString();
 }
 
-QString FileUtils::resolveSymlink(const QUrl &url) {
+QString FileUtils::resolveSymlink(const QUrl &url)
+{
     QSet<QString> visited;
     QString target = symlinkTarget(url);
     while (!target.isEmpty()) {
@@ -1143,181 +1029,6 @@ QString FileUtils::resolveSymlink(const QUrl &url) {
     return target;
 }
 
-bool FileUtils::isSymbol(const QChar ch)
-{
-    // 如果是高代理项，不应该单独判断
-    if (ch.isHighSurrogate() || ch.isLowSurrogate())
-        return false;
-
-    QChar normalized;
-    if (isFullWidthChar(ch, normalized)) {
-        return isSymbol(normalized);
-    }
-
-    // 对于普通字符进行原有判断
-    return ch.script() != QChar::Script_Han && !isNumOrChar(ch);
-}
-
-QString FileUtils::numberStr(const QString &str, int pos)
-{
-    QString tmp;
-    auto total = str.length();
-
-    while (pos > 0 && isNumber(str.at(pos))) {
-        pos--;
-    }
-
-    if (!isNumber(str.at(pos)))
-        pos++;
-
-    while (pos < total && isNumber(str.at(pos))) {
-        const QChar &ch = str.at(pos);
-        QChar number;
-        if (isFullWidthChar(ch, number)) {
-            tmp += number;   // 将全角数字转换为半角数字
-        } else {
-            tmp += ch;
-        }
-        pos++;
-    }
-
-    return tmp;
-}
-
-// 升序，第一个小，true
-bool FileUtils::compareByStringEx(const QString &str1, const QString &str2)
-{
-    thread_local static DCollator sortCollator;
-    QString suf1 = str1.right(str1.length() - str1.lastIndexOf(".") - 1);
-    QString suf2 = str2.right(str2.length() - str2.lastIndexOf(".") - 1);
-    QString name1 = str1.left(str1.lastIndexOf("."));
-    QString name2 = str2.left(str2.lastIndexOf("."));
-
-    bool preIsNum = false;
-    bool isSymbol1 = false, isSymbol2 = false, isHanzi1 = false,
-         isHanzi2 = false, isNumb1 = false, isNumb2 = false;
-
-    // 使用迭代器来正确处理代理对字符
-    QString::const_iterator it1 = name1.constBegin();
-    QString::const_iterator it2 = name2.constBegin();
-
-    while (it1 != name1.constEnd() && it2 != name2.constEnd()) {
-        // 获取当前完整字符(可能是代理对)
-        uint unicode1 = it1->isHighSurrogate() && (it1 + 1) != name1.constEnd()
-                ? QChar::surrogateToUcs4(*it1, *(it1 + 1))
-                : it1->unicode();
-        uint unicode2 = it2->isHighSurrogate() && (it2 + 1) != name2.constEnd()
-                ? QChar::surrogateToUcs4(*it2, *(it2 + 1))
-                : it2->unicode();
-
-        // 如果字符相同，继续比较下一个
-        if (unicode1 == unicode2) {
-            preIsNum = isNumber(*it1);
-            if (it1->isHighSurrogate()) {
-                ++it1;
-                ++it2;
-            }
-            ++it1;
-            ++it2;
-            continue;
-        }
-
-        // 处理数字
-        QChar number1, number2;
-        isNumb1 = !it1->isHighSurrogate() && isNumber(*it1);
-        isNumb2 = !it2->isHighSurrogate() && isNumber(*it2);
-
-        if ((preIsNum && (isNumb1 ^ isNumb2)) || (isNumb1 && isNumb2)) {
-            auto str1n = numberStr(name1, it1 - name1.constBegin()).toUInt();
-            auto str2n = numberStr(name2, it2 - name2.constBegin()).toUInt();
-            if (str1n == str2n) {
-                // 如果数值相同，全角数字排在半角数字后面
-                bool isFullWidth1 = isFullWidthChar(*it1, number1);
-                bool isFullWidth2 = isFullWidthChar(*it2, number2);
-                if (isFullWidth1 != isFullWidth2)
-                    return !isFullWidth1;
-                return unicode1 < unicode2;
-            }
-            return str1n < str2n;
-        }
-
-        // 处理特殊字符
-        QChar normalized1, normalized2;
-        bool isFullWidth1 = isFullWidthChar(*it1, normalized1);
-        bool isFullWidth2 = isFullWidthChar(*it2, normalized2);
-
-        isSymbol1 = !it1->isHighSurrogate() && isSymbol(*it1);
-        isSymbol2 = !it2->isHighSurrogate() && isSymbol(*it2);
-
-        // 如果都是符号，先比较归一化后的字符
-        if (isSymbol1 && isSymbol2) {
-            QChar ch1 = isFullWidth1 ? normalized1 : *it1;
-            QChar ch2 = isFullWidth2 ? normalized2 : *it2;
-            if (ch1 != ch2)
-                return ch1 < ch2;
-            // 如果归一化后相同，全角排在半角后面
-            if (isFullWidth1 != isFullWidth2)
-                return !isFullWidth1;
-            // 如果全半角属性也相同，继续比较下一个字符
-            if (it1->isHighSurrogate()) {
-                ++it1;
-                ++it2;
-            }
-            ++it1;
-            ++it2;
-            continue;
-        }
-
-        // 如果一个是符号一个不是，符号排在后面
-        if (isSymbol1 ^ isSymbol2)
-            return isSymbol2;
-
-        // 处理汉字(包括扩展汉字)
-        QChar::Script script1 = it1->isHighSurrogate() ? QChar::script(unicode1) : it1->script();
-        QChar::Script script2 = it2->isHighSurrogate() ? QChar::script(unicode2) : it2->script();
-        isHanzi1 = script1 == QChar::Script_Han;
-        isHanzi2 = script2 == QChar::Script_Han;
-
-        if (isHanzi2 ^ isHanzi1)
-            return !isHanzi1;
-        if (isHanzi1) {
-            // 直接使用 QString 构造包含单个 Unicode 码点的字符串
-            QString str1 = makeQString(it1, unicode1);
-            QString str2 = makeQString(it2, unicode2);
-            return sortCollator.compare(str1, str2) < 0;
-        }
-
-        // 处理普通字符
-        if (!isNumb1 && !isNumb2) {
-            QString str1 = makeQString(it1, unicode1);
-            QString str2 = makeQString(it2, unicode2);
-            return str1.toLower() < str2.toLower();
-        }
-
-        return isNumb1;
-    }
-
-    // 如果前面的字符都相同，较短的字符串排在前面
-    if (it1 == name1.constEnd())
-        return true;
-    if (it2 == name2.constEnd())
-        return false;
-
-    // 处理后缀
-    if (suf1.isEmpty() ^ suf2.isEmpty())
-        return suf1.isEmpty();
-
-    if (suf2.startsWith(suf1) ^ suf1.startsWith(suf2))
-        return suf2.startsWith(suf1);
-
-    return suf1 < suf2;
-}
-
-bool FileUtils::compareString(const QString &str1, const QString &str2, Qt::SortOrder order)
-{
-    return !((order == Qt::AscendingOrder) ^ compareByStringEx(str1, str2));
-}
-
 QString FileUtils::encryptString(const QString &str)
 {
     QByteArray byteArray = str.toUtf8();
@@ -1453,13 +1164,51 @@ int FileUtils::dirFfileCount(const QUrl &url)
 
 bool FileUtils::fileCanTrash(const QUrl &url)
 {
-    // gio does not support root user to move ordinary user files to trash
     auto info = InfoFactory::create<FileInfo>(url, Global::CreateFileInfoType::kCreateFileInfoSync);
-    if (!info)
+    if (!info) {
+        qCWarning(logDFMBase) << "Failed to create file info for URL:" << url;
         return false;
+    }
 
-    if (SysInfoUtils::isRootUser())
-        return info->canAttributes(CanableInfoType::kCanTrash);
+    // gio does not support root user to move ordinary user files to trash
+    if (SysInfoUtils::isRootUser()) {
+        int currentEffectiveUid = SysInfoUtils::getUserId();
+        int ownerId = info->extendAttributes(FileInfo::FileExtendedInfoType::kOwnerId).toInt();
+        if (ownerId != currentEffectiveUid) {
+            qCWarning(logDFMBase) << "A root process is trying to trash a non-root file, predicting failure.";
+            return false;
+        }
+    }
+
+    // 检查文件是否位于原始用户的“领域”（主目录）内
+    if (SysInfoUtils::isOpenAsAdmin()) {
+        const QString &originalHomePath = SysInfoUtils::getOriginalUserHome();
+        const QString &canonicalFilePath = info->pathOf(PathInfoType::kCanonicalPath);   // 获取文件所在目录的规范路径
+        if (originalHomePath.isEmpty() || canonicalFilePath.isEmpty()) {
+            qCWarning(logDFMBase) << "Invalid path detected: originalHomePath or canonicalFilePath is empty.";
+            return false;   // 路径无效
+        }
+
+        // Use more reliable path comparison to handle symlinks and mount points
+        QString normalizedOriginalHome = QDir::cleanPath(originalHomePath);
+        QString normalizedFilePath = QDir::cleanPath(canonicalFilePath);
+
+        // Ensure proper path boundary comparison
+        if (!normalizedOriginalHome.endsWith('/')) {
+            normalizedOriginalHome += '/';
+        }
+
+        // Check if file is within the original user's home directory
+        bool isInHomeDir = (normalizedFilePath.startsWith(normalizedOriginalHome) || normalizedFilePath == normalizedOriginalHome.chopped(1));
+
+        if (isInHomeDir) {
+            // 文件位于原始用户的主目录中。
+            // 这是 GIO 会拒绝的“领域冲突”场景。
+            qCWarning(logDFMBase) << " A root process is trying to trash a file inside another user's home directory ("
+                                  << url << "). Predicting GIO failure.";
+            return false;
+        }
+    }
 
     bool alltotrash = DConfigManager::instance()->value(kDefaultCfgPath, kFileAllTrash).toBool();
     if (alltotrash)
