@@ -10,7 +10,7 @@
 DFMBASE_USE_NAMESPACE
 
 namespace dfmplugin_emblem {
-DFM_LOG_REISGER_CATEGORY(DPEMBLEM_NAMESPACE)
+DFM_LOG_REGISTER_CATEGORY(DPEMBLEM_NAMESPACE)
 
 void Emblem::initialize()
 {
