@@ -8,6 +8,7 @@
 
 #include <dfm-base/utils/fileutils.h>
 #include <dfm-base/utils/sysinfoutils.h>
+#include <dfm-base/utils/sortutils.h>
 #include <dfm-base/base/application/application.h>
 
 #include <dfm-framework/event/event.h>
@@ -301,7 +302,7 @@ bool CanvasProxyModelPrivate::lessThan(const QUrl &left, const QUrl &right) cons
     auto compareByName = [this, leftIdx, rightIdx]() {
         QString leftName = q->data(leftIdx, kItemFileDisplayNameRole).toString();
         QString rightName = q->data(rightIdx, kItemFileDisplayNameRole).toString();
-        return FileUtils::compareString(leftName, rightName, fileSortOrder);
+        return SortUtils::compareString(leftName, rightName, fileSortOrder);
     };
 
     switch (fileSortRole) {
@@ -311,7 +312,7 @@ bool CanvasProxyModelPrivate::lessThan(const QUrl &left, const QUrl &right) cons
     case kItemFileDisplayNameRole: {
         QString leftString = leftData.toString();
         QString rightString = rightData.toString();
-        return leftString == rightString ? compareByName() : FileUtils::compareString(leftString, rightString, fileSortOrder);
+        return leftString == rightString ? compareByName() : SortUtils::compareString(leftString, rightString, fileSortOrder);
     }
     case kItemFileSizeRole: {
         qint64 leftSize = leftData.toLongLong();
