@@ -88,12 +88,12 @@ ComputerDataList ComputerItemWatcher::items()
     // only sort disk area.
     std::sort(ret.begin() + diskStartPos, ret.end(), ComputerItemWatcher::typeCompare);
 
-    // 性能优化，读取插件配置，在插件被加载前预先绘制出插件在计算机的图标和名称
-    ret.append(getPreDefineItems());
-
     if (!hasInsertNewDisk)
         ret.pop_back();
 
+    // 性能优化，读取插件配置，在插件被加载前预先绘制出插件在计算机的图标和名称
+    ret.append(getPreDefineItems());
+
     return ret;
 }
 
@@ -113,7 +113,7 @@ void ComputerItemWatcher::initConn()
         auto appUrl = ComputerUtils::makeAppEntryUrl(url.path());
         if (!appUrl.isValid())
             return;
-        this->onDeviceAdded(appUrl, getGroupId(diskGroup()), ComputerItemData::kLargeItem, false);
+        addDevice(diskGroup(), appUrl, ComputerItemData::kLargeItem, false);
     });
     connect(appEntryWatcher.data(), &LocalFileWatcher::fileDeleted, this, [this](const QUrl &url) {
         auto appUrl = ComputerUtils::makeAppEntryUrl(url.path());
@@ -213,7 +213,7 @@ ComputerDataList ComputerItemWatcher::getBlockDeviceItems(bool *hasNewItem)
             insertUrlMapper(dev, info->targetUrl());
 
         if (!hiddenByDConfig.contains(devUrl))   // do not show item which hidden by dconfig
-            sidebarInfos.insert(info->urlOf(UrlInfoType::kUrl), makeSidebarItem(info));
+            pendingSidebarDevUrls.append(devUrl);   // Record devUrl, delay makeSidebarItem execution to main thread
     }
     fmInfo() << "end querying block info";
 
@@ -248,7 +248,7 @@ ComputerDataList ComputerItemWatcher::getProtocolDeviceItems(bool *hasNewItem)
         ret.push_back(data);
         *hasNewItem = true;
 
-        sidebarInfos.insert(info->urlOf(UrlInfoType::kUrl), makeSidebarItem(info));
+        pendingSidebarDevUrls.append(devUrl);   // Record devUrl, delay makeSidebarItem execution to main thread
     }
 
     fmInfo() << "end querying protocol devices info";
@@ -405,13 +405,13 @@ QList<QUrl> ComputerItemWatcher::disksHiddenByDConf()
 {
     const auto &&currHiddenDisks = DConfigManager::instance()->value(kDefaultCfgPath, kHideDisk).toStringList();
     const auto &&allBlockUUIDs = ComputerUtils::allValidBlockUUIDs();
-    
+
     QSet<QString> hiddenSet(currHiddenDisks.begin(), currHiddenDisks.end());
     QSet<QString> uuidSet(allBlockUUIDs.begin(), allBlockUUIDs.end());
-    
+
     QSet<QString> intersection = hiddenSet;
     intersection.intersect(uuidSet);
-    
+
     return ComputerUtils::blkDevUrlByUUIDs(QList<QString>(intersection.begin(), intersection.end()));
 }
 
@@ -419,7 +419,7 @@ QList<QUrl> ComputerItemWatcher::disksHiddenBySettingPanel()
 {
     auto systemBlocksAndLoopList = DevProxyMng->getAllBlockIds(GlobalServerDefines::DeviceQueryOption::kSystem);
     auto loopOnlyList = DevProxyMng->getAllBlockIds(GlobalServerDefines::DeviceQueryOption::kLoop);
-    
+
     QSet<QString> systemBlocksAndLoop(systemBlocksAndLoopList.begin(), systemBlocksAndLoopList.end());
     QSet<QString> loopOnly(loopOnlyList.begin(), loopOnlyList.end());
 
@@ -447,7 +447,7 @@ QList<QUrl> ComputerItemWatcher::hiddenPartitions()
     QList<QUrl> hiddenUrls;
     hiddenUrls += disksHiddenByDConf();
     hiddenUrls += disksHiddenBySettingPanel();
-    
+
     QSet<QUrl> uniqueUrls(hiddenUrls.begin(), hiddenUrls.end());
     return QList<QUrl>(uniqueUrls.begin(), uniqueUrls.end());
 }
@@ -599,6 +599,15 @@ void ComputerItemWatcher::handleSidebarItemsVisiable()
         addSidebarItem(info);
 }
 
+bool ComputerItemWatcher::removeGroup(const QString &groupName)
+{
+    if (groupIds.contains(groupName)) {
+        groupIds.remove(groupName);
+        return true;
+    }
+    return false;
+}
+
 void ComputerItemWatcher::insertUrlMapper(const QString &devId, const QUrl &mntUrl)
 {
     QUrl devUrl;
@@ -772,6 +781,7 @@ void ComputerItemWatcher::startQueryItems(bool async)
 {
     isItemQueryFinished = false;
     sidebarInfos.clear();
+    pendingSidebarDevUrls.clear();   // Clear pending URL list
 
     auto afterQueryFunc = [this]() {
         QList<QUrl> computerItems;
@@ -787,8 +797,11 @@ void ComputerItemWatcher::startQueryItems(bool async)
                 removeSidebarItem(url);
                 sidebarInfos.remove(url);
                 initedDatas.removeAt(i);
+            } else if (pendingSidebarDevUrls.contains(url)) {
+                sidebarInfos.insert(url, makeSidebarItem(initedDatas[i].info));
             }
         }
+        pendingSidebarDevUrls.clear();   // Clear the list
 
         for (const auto &key : sidebarInfos.keys()) {
             const auto &value = sidebarInfos.value(key);
@@ -808,7 +821,7 @@ void ComputerItemWatcher::startQueryItems(bool async)
             fw->deleteLater();
             fw = nullptr;
         });
-        
+
         auto future = QtConcurrent::run([this]() {
             return this->items();
         });
@@ -908,7 +921,7 @@ void ComputerItemWatcher::onDevicePropertyChangedQDBusVar(const QString &id, con
             auto blkInfo = DevProxyMng->queryBlockInfo(id);
             if (blkInfo.value(DeviceProperty::kIsLoopDevice).toBool()) {
                 if (var.variant().toBool())
-                    onDeviceAdded(url, getGroupId(diskGroup()));
+                    addDevice(diskGroup(), url);
                 else
                     removeDevice(url);
             }
@@ -944,7 +957,7 @@ void ComputerItemWatcher::onDConfigChanged(const QString &cfg, const QString &cf
 void ComputerItemWatcher::onBlockDeviceAdded(const QString &id)
 {
     QUrl url = ComputerUtils::makeBlockDevUrl(id);
-    onDeviceAdded(url, getGroupId(diskGroup()));
+    addDevice(diskGroup(), url);
 }
 
 void ComputerItemWatcher::onBlockDeviceRemoved(const QString &id)
@@ -977,7 +990,7 @@ void ComputerItemWatcher::onProtocolDeviceMounted(const QString &id, const QStri
 
     auto url = ComputerUtils::makeProtocolDevUrl(id);
 
-    this->onDeviceAdded(url, getGroupId(diskGroup()));
+    addDevice(diskGroup(), url);
 }
 
 void ComputerItemWatcher::onProtocolDeviceUnmounted(const QString &id)
