@@ -17,8 +17,10 @@ CrumbManager *CrumbManager::instance()
 
 void CrumbManager::registerCrumbCreator(const CrumbManager::KeyType &scheme, const CrumbManager::CrumbCreator &creator)
 {
-    if (isRegistered(scheme))
+    if (isRegistered(scheme)) {
+        fmWarning() << "Crumb creator for scheme" << scheme << "is already registered";
         return;
+    }
 
     creators.insert(scheme, creator);
 }
@@ -32,7 +34,7 @@ CrumbInterface *CrumbManager::createControllerByUrl(const QUrl &url)
 {
     KeyType &&theType = url.scheme();
     if (!creators.contains(theType)) {
-        fmWarning() << "Scheme: " << theType << "not registered!";
+        fmWarning() << "Cannot create crumb controller: scheme" << theType << "not registered";
         return nullptr;
     }
 
