@@ -10,6 +10,7 @@
 #include "utils/crumbmanager.h"
 
 #include <dfm-io/denumerator.h>
+#include <dfm-io/dfmio_utils.h>
 #include <dfm-base/utils/protocolutils.h>
 
 #include <DStyle>
@@ -202,12 +203,15 @@ void UrlPushButtonPrivate::onSelectSubDirs()
 
     // 如果已经显示则隐藏
     if (folderListWidget && folderListWidget->isVisible()) {
+        fmDebug() << "Hiding existing folder list widget";
         folderListWidget->hide();
         return;
     }
 
-    if (crumbDatas.isEmpty())
+    if (crumbDatas.isEmpty()) {
+        fmWarning() << "Cannot select subdirs: crumb data is empty";
         return;
+    }
 
     // 保存 crumbBar 的弱引用
     QPointer<CrumbBar> weakCrumbBar(crumbBar);
@@ -251,13 +255,21 @@ void UrlPushButtonPrivate::onCompletionFound(const QStringList &stringList)
 
 void UrlPushButtonPrivate::onCompletionCompleted()
 {
-    if (!folderListWidget || completionStringList.isEmpty() || crumbDatas.isEmpty())
+    if (!folderListWidget || completionStringList.isEmpty() || crumbDatas.isEmpty()) {
+        fmWarning() << "Cannot complete: missing widget, completion data, or crumb data";
         return;
+    }
     QList<CrumbData> datas;
     for (int i = 0; i < completionStringList.size(); ++i) {
         CrumbData data;
         data.displayText = completionStringList[i];
-        data.url = QUrl(crumbDatas.last().url.url() + '/' + completionStringList[i]);
+        // 使用 DFMIO::DFMUtils::buildFilePath 正确构造路径，然后使用 QUrl::fromLocalFile 创建 URL
+        // Why? 一个例子是“！殊字符#$%$............{【.,”，直接拼接会出错
+        const QString parentPath = crumbDatas.last().url.toLocalFile();
+        const QString childPath = DFMIO::DFMUtils::buildFilePath(parentPath.toStdString().c_str(),
+                                                                 completionStringList[i].toStdString().c_str(),
+                                                                 nullptr);
+        data.url = QUrl::fromLocalFile(childPath);
         datas.append(data);
     }
     const bool leftToRight = (q->layoutDirection() == Qt::LeftToRight);
@@ -339,7 +351,7 @@ void UrlPushButton::paintEvent(QPaintEvent *event)
         updateWidth();
     }
     QPainter painter(this);
-    painter.setRenderHint(QPainter::Antialiasing);
+    painter.setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform | QPainter::TextAntialiasing);
 
     // 绘制悬停或菜单状态
     if (d->hoverFlag || d->popupVisible()) {
