@@ -87,6 +87,7 @@ QUrl VaultHelper::pathToVaultVirtualUrl(const QString &path)
         virtualUrl.setHost("");
         return virtualUrl;
     }
+    fmWarning() << "Vault: Path does not contain local path, returning empty URL";
     return QUrl();
 }
 
@@ -98,16 +99,23 @@ QUrl VaultHelper::pathToVaultVirtualUrl(const QString &path)
  */
 void VaultHelper::contenxtMenuHandle(quint64 windowId, const QUrl &url, const QPoint &globalPos)
 {
+    fmDebug() << "Vault: Handling context menu for window ID:" << windowId << "URL:" << url.toString() << "Position:" << globalPos;
+
     VaultHelper::instance()->appendWinID(windowId);
     DMenu *menu = createMenu();
 #ifdef ENABLE_TESTING
     dpfSlotChannel->push("dfmplugin_utils", "slot_Accessible_SetAccessibleName",
                          qobject_cast<QWidget *>(menu), AcName::kAcSidebarVaultMenu);
 #endif
+
+    fmDebug() << "Vault: Executing context menu";
     QAction *act = menu->exec(globalPos);
     if (act) {
         QList<QUrl> urls { url };
+        fmInfo() << "Vault: Context menu action triggered:" << act->text();
         dpfSignalDispatcher->publish("dfmplugin_vault", "signal_ReportLog_MenuData", act->text(), urls);
+    } else {
+        fmDebug() << "Vault: Context menu closed without action selection";
     }
     delete menu;
 }
@@ -124,12 +132,15 @@ void VaultHelper::siderItemClicked(quint64 windowId, const QUrl &url)
 
     switch (instance()->state(PathManager::vaultLockPath())) {
     case VaultState::kNotExisted: {
+        fmInfo() << "Vault: Vault not existed, showing create dialog";
         VaultHelper::instance()->createVaultDialog();
     } break;
     case VaultState::kEncrypted: {
+        fmInfo() << "Vault: Vault encrypted, showing unlock dialog";
         VaultHelper::instance()->unlockVaultDialog();
     } break;
     case VaultState::kUnlocked:
+        fmInfo() << "Vault: Vault unlocked, performing default action";
         instance()->defaultCdAction(windowId, url);
         recordTime(kjsonGroupName, kjsonKeyInterviewItme);
         break;
@@ -137,6 +148,7 @@ void VaultHelper::siderItemClicked(quint64 windowId, const QUrl &url)
     case VaultState::kBroken:
         break;
     case VaultState::kNotAvailable: {
+        fmWarning() << "Vault: Vault not available - cryfs not installed";
         DialogManagerInstance->showErrorDialog(tr("Vault"), tr("Vault not available because cryfs not installed!"));
     } break;
     default:
@@ -166,11 +178,18 @@ void VaultHelper::openNewWindow(const QUrl &url)
 
 bool VaultHelper::getVaultVersion() const
 {
+    fmDebug() << "Vault: Checking vault version";
+
     VaultConfig config;
     QString strVersion = config.get(kConfigNodeName, kConfigKeyVersion).toString();
-    if (!strVersion.isEmpty() && strVersion != kConfigVaultVersion)
-        return true;
+    fmDebug() << "Vault: Current version:" << strVersion << "Expected:" << kConfigVaultVersion;
 
+    if (!strVersion.isEmpty() && strVersion != kConfigVaultVersion) {
+        fmInfo() << "Vault: Version mismatch detected";
+        return true;
+    }
+
+    fmDebug() << "Vault: Version check passed";
     return false;
 }
 
@@ -192,16 +211,31 @@ void VaultHelper::removeWinID(const quint64 &winId)
 
 bool VaultHelper::enableUnlockVault()
 {
+    fmDebug() << "Vault: Checking if vault unlock is enabled";
+
     const QVariant vRe = DConfigManager::instance()->value(kVaultDConfigName, "enableUnlockVaultInNetwork");
-    if (!vRe.isValid())
+    if (!vRe.isValid()) {
+        fmDebug() << "Vault: Config not found, enabling unlock";
         return true;
+    }
 
     bool bRe = vRe.toBool();
-    if (bRe)
-        return true;
+    fmDebug() << "Vault: Config value for enableUnlockVaultInNetwork:" << bRe;
 
-    if (VaultDBusUtils::isFullConnectInternet())
+    if (bRe) {
+        fmDebug() << "Vault: Unlock enabled in config";
+        return true;
+    }
+
+    bool isConnected = VaultDBusUtils::isFullConnectInternet();
+    fmDebug() << "Vault: Internet connection status:" << isConnected;
+
+    if (isConnected) {
+        fmWarning() << "Vault: Unlock disabled due to internet connection";
         return false;
+    }
+
+    fmDebug() << "Vault: Unlock enabled (no internet connection)";
     return true;
 }
 
@@ -214,63 +248,83 @@ void VaultHelper::appendWinID(const quint64 &winId)
 
 DMenu *VaultHelper::createMenu()
 {
+    fmDebug() << "Vault: Creating context menu";
+
     DMenu *menu = new DMenu;
     DMenu *timeMenu = new DMenu(menu);
     switch (instance()->state(PathManager::vaultLockPath())) {
     case VaultState::kNotExisted:
+        fmDebug() << "Vault: Adding 'Create Vault' menu item";
         menu->addAction(QObject::tr("Create Vault"), VaultHelper::instance(), &VaultHelper::createVaultDialog);
         break;
     case VaultState::kEncrypted:
+        fmDebug() << "Vault: Adding 'Unlock' menu item";
         menu->addAction(QObject::tr("Unlock"), VaultHelper::instance(), &VaultHelper::unlockVaultDialog);
         break;
     case VaultState::kUnlocked: {
+        fmDebug() << "Vault: Adding unlocked state menu items";
+
         menu->addAction(QObject::tr("Open"), VaultHelper::instance(), &VaultHelper::openWindow);
-
         menu->addAction(QObject::tr("Open in new window"), VaultHelper::instance(), &VaultHelper::newOpenWindow);
-
         menu->addSeparator();
 
         VaultConfig config;
         QString encryptionMethod = config.get(kConfigNodeName, kConfigKeyEncryptionMethod, QVariant(kConfigKeyNotExist)).toString();
+        fmDebug() << "Vault: Encryption method:" << encryptionMethod;
+
         if (encryptionMethod == QString(kConfigValueMethodKey) || encryptionMethod == QString(kConfigKeyNotExist)) {
+            fmDebug() << "Vault: Adding key-based encryption menu items";
+
             menu->addAction(QObject::tr("Lock"), []() {
+                fmInfo() << "Vault: Manual lock action triggered";
                 VaultHelper::instance()->lockVault(false);
             });
 
             QAction *timeLock = new QAction;
             timeLock->setText(QObject::tr("Auto lock"));
             VaultAutoLock::AutoLockState autoState = VaultAutoLock::instance()->getAutoLockState();
+            fmDebug() << "Vault: Current auto-lock state:" << static_cast<int>(autoState);
+
             QAction *actionNever = timeMenu->addAction(QObject::tr("Never"), []() {
+                fmInfo() << "Vault: Setting auto-lock to Never";
                 VaultAutoLock::instance()->autoLock(VaultAutoLock::AutoLockState::kNever);
             });
             actionNever->setCheckable(true);
             actionNever->setChecked(VaultAutoLock::AutoLockState::kNever == autoState ? true : false);
+
             timeMenu->addSeparator();
+
             QAction *actionFiveMins = timeMenu->addAction(QObject::tr("5 minutes"), []() {
+                fmInfo() << "Vault: Setting auto-lock to 5 minutes";
                 VaultAutoLock::instance()->autoLock(VaultAutoLock::AutoLockState::kFiveMinutes);
             });
             actionFiveMins->setCheckable(true);
             actionFiveMins->setChecked(VaultAutoLock::AutoLockState::kFiveMinutes == autoState ? true : false);
+
             QAction *actionTenMins = timeMenu->addAction(QObject::tr("10 minutes"), []() {
+                fmInfo() << "Vault: Setting auto-lock to 10 minutes";
                 VaultAutoLock::instance()->autoLock(VaultAutoLock::AutoLockState::kTenMinutes);
             });
             actionTenMins->setCheckable(true);
             actionTenMins->setChecked(VaultAutoLock::AutoLockState::kTenMinutes == autoState ? true : false);
+
             QAction *actionTwentyMins = timeMenu->addAction(QObject::tr("20 minutes"), []() {
+                fmInfo() << "Vault: Setting auto-lock to 20 minutes";
                 VaultAutoLock::instance()->autoLock(VaultAutoLock::AutoLockState::kTwentyMinutes);
             });
             actionTwentyMins->setCheckable(true);
             actionTwentyMins->setChecked(VaultAutoLock::AutoLockState::kTwentyMinutes == autoState ? true : false);
+
             timeLock->setMenu(timeMenu);
-
             menu->addMenu(timeMenu);
-
             menu->addSeparator();
+
+            fmDebug() << "Vault: Auto-lock menu items added";
         }
 
         menu->addAction(QObject::tr("Delete File Vault"), VaultHelper::instance(), &VaultHelper::showRemoveVaultDialog);
-
         menu->addAction(QObject::tr("Properties"), []() {
+            fmInfo() << "Vault: Properties action triggered";
             VaultEventCaller::sendVaultProperty(VaultHelper::instance()->rootUrl());
         });
     } break;
@@ -281,6 +335,7 @@ DMenu *VaultHelper::createMenu()
         break;
     }
 
+    fmDebug() << "Vault: Menu creation completed";
     return menu;
 }
 
@@ -293,11 +348,13 @@ QWidget *VaultHelper::createVaultPropertyDialog(const QUrl &url)
     bool flg1 = UniversalUtils::urlEquals(tempUrl, url);
     if (flg || flg1) {
         if (!vaultDialog) {
+            fmDebug() << "Vault: Creating new property dialog";
             vaultDialog = new VaultPropertyDialog();
             vaultDialog->selectFileUrl(url);
             connect(vaultDialog, &VaultPropertyDialog::finished, []() { vaultDialog = nullptr; });
             return vaultDialog;
         }
+        fmDebug() << "Vault: Returning existing property dialog";
         return vaultDialog;
     }
     return nullptr;
@@ -305,13 +362,18 @@ QWidget *VaultHelper::createVaultPropertyDialog(const QUrl &url)
 
 QUrl VaultHelper::vaultToLocalUrl(const QUrl &url)
 {
-    if (url.scheme() != instance()->scheme())
+    if (url.scheme() != instance()->scheme()) {
+        fmWarning() << "Vault: URL scheme mismatch, expected:" << instance()->scheme() << "got:" << url.scheme();
         return QUrl();
+    }
+
     if (url.path().contains(instance()->sourceRootUrl().path())) {
         QUrl localUrl = QUrl::fromLocalFile(url.path());
+        fmDebug() << "Vault: Direct path conversion - local URL:" << localUrl.toString();
         return localUrl;
     } else {
         QUrl localUrl = QUrl::fromLocalFile(instance()->sourceRootUrl().path() + url.path());
+        fmDebug() << "Vault: Path concatenation - local URL:" << localUrl.toString();
         return localUrl;
     }
 }
@@ -334,49 +396,78 @@ bool VaultHelper::lockVault(bool isForced)
 
 void VaultHelper::createVaultDialog()
 {
-    if (QFile::exists(kVaultBasePathOld + QDir::separator() + QString(kVaultEncrypyDirName) + QDir::separator() + QString(kCryfsConfigFileName))) {
+    fmDebug() << "Vault: Showing create vault dialog";
+    QString oldVaultPath = kVaultBasePathOld + QDir::separator() + QString(kVaultEncrypyDirName) + QDir::separator() + QString(kCryfsConfigFileName);
+    if (QFile::exists(oldVaultPath)) {
         fmCritical() << "Vault: the old vault not migrate";
         return;
     }
     VaultPageBase *page = new VaultActiveView();
     page->exec();
-    if (state(PathManager::vaultLockPath()) == kNotExisted)
+
+    if (state(PathManager::vaultLockPath()) == kNotExisted) {
+        fmDebug() << "Vault: Vault still not existed after dialog, updating sidebar selection";
         dpfSlotChannel->push("dfmplugin_sidebar", "slot_Sidebar_UpdateSelection", currentWinID);
+    }
 }
 
 void VaultHelper::unlockVaultDialog()
 {
+    fmDebug() << "Vault: Showing unlock vault dialog";
+
     VaultConfig config;
     QString encryptionMethod = config.get(kConfigNodeName, kConfigKeyEncryptionMethod, QVariant(kConfigKeyNotExist)).toString();
+    fmDebug() << "Vault: Encryption method:" << encryptionMethod;
+
     if (encryptionMethod == QString(kConfigValueMethodTransparent)) {
+        fmDebug() << "Vault: Using transparent encryption method";
+
         const QString &password = OperatorCenter::getInstance()->passwordFromKeyring();
         if (!password.isEmpty()) {
+            fmDebug() << "Vault: Password retrieved from keyring, attempting unlock";
+
             if (unlockVault(password)) {
+                fmInfo() << "Vault: Automatic unlock successful";
                 VaultHelper::instance()->defaultCdAction(VaultHelper::instance()->currentWindowId(),
                                                          VaultHelper::instance()->rootUrl());
                 VaultHelper::recordTime(kjsonGroupName, kjsonKeyInterviewItme);
+            } else {
+                fmWarning() << "Vault: Automatic unlock failed";
             }
         } else {
             fmWarning() << "Vault: The password from Keyring is empty!";
         }
     } else {
+        fmDebug() << "Vault: Using key-based encryption method, showing unlock pages";
+
         VaultUnlockPages *page = new VaultUnlockPages();
         page->pageSelect(PageType::kUnlockPage);
         page->exec();
-        if (state(PathManager::vaultLockPath()) != kUnlocked)
+
+        if (state(PathManager::vaultLockPath()) != kUnlocked) {
+            fmDebug() << "Vault: Vault not unlocked after dialog, updating sidebar selection";
             dpfSlotChannel->push("dfmplugin_sidebar", "slot_Sidebar_UpdateSelection", currentWinID);
+        }
     }
 }
 
 void VaultHelper::showRemoveVaultDialog()
 {
+    fmDebug() << "Vault: Showing remove vault dialog";
+
     VaultConfig config;
     QString encryptionMethod = config.get(kConfigNodeName, kConfigKeyEncryptionMethod, QVariant(kConfigKeyNotExist)).toString();
+    fmDebug() << "Vault: Encryption method for removal:" << encryptionMethod;
+
     if (kConfigValueMethodKey == encryptionMethod || kConfigKeyNotExist == encryptionMethod) {
+        fmDebug() << "Vault: Showing password-based removal dialog";
+
         VaultRemovePages *page = new VaultRemovePages(qApp->activeWindow());
         page->pageSelect(kPasswordWidget);
         page->exec();
     } else if (kConfigValueMethodTransparent == encryptionMethod) {
+        fmDebug() << "Vault: Showing transparent removal dialog";
+
         VaultRemovePages *page = new VaultRemovePages(qApp->activeWindow());
         page->pageSelect(kNoneWidget);
         page->exec();
@@ -403,6 +494,8 @@ void VaultHelper::newOpenWindow()
 void VaultHelper::slotlockVault(int state)
 {
     if (state == 0) {
+        fmDebug() << "Vault: Vault locked successfully, notifying components";
+
         VaultAutoLock::instance()->slotLockVault(state);
         emit VaultHelper::instance()->sigLocked(state);
         QUrl url;
@@ -412,6 +505,8 @@ void VaultHelper::slotlockVault(int state)
             defaultCdAction(wid, url);
         }
         recordTime(kjsonGroupName, kjsonKeyLockTime);
+    } else {
+        fmWarning() << "Vault: Lock operation failed with state:" << state;
     }
 }
 
@@ -438,16 +533,23 @@ bool VaultHelper::isVaultFile(const QUrl &url)
 
 bool VaultHelper::urlsToLocal(const QList<QUrl> &origins, QList<QUrl> *urls)
 {
-    if (!urls)
+    if (!urls) {
+        fmWarning() << "Vault: Output URL list is null";
         return false;
+    }
+
     for (const QUrl &url : origins) {
-        if (!isVaultFile(url))
+        if (!isVaultFile(url)) {
+            fmWarning() << "Vault: URL is not a vault file:" << url.toString();
             return false;
+        }
+
         if (url.scheme() == VaultHelper::instance()->scheme())
             (*urls).push_back(vaultToLocalUrl(url));
         else
             (*urls).push_back(url);
     }
+
     return true;
 }
 
@@ -455,15 +557,20 @@ void VaultHelper::showInProgressDailog(QString msg)
 {
     //期间有拷贝，压缩任务时，提示不可上锁
     if (msg.contains("Device or resource busy")) {
+        fmWarning() << "Vault: Device busy error detected";
         DialogManagerInstance->showErrorDialog(tr("Vault"), tr("A task is in progress, so it cannot perform your operation"));
     }
 }
 
 VaultHelper::VaultHelper()
 {
+    fmDebug() << "Vault: Initializing VaultHelper";
+
     connect(FileEncryptHandle::instance(), &FileEncryptHandle::signalCreateVault, this, &VaultHelper::sigCreateVault);
     connect(FileEncryptHandle::instance(), &FileEncryptHandle::signalUnlockVault, this, &VaultHelper::sigUnlocked);
     connect(FileEncryptHandle::instance(), &FileEncryptHandle::signalLockVault, this, &VaultHelper::slotlockVault);
     connect(FileEncryptHandle::instance(), &FileEncryptHandle::signalReadError, this, &VaultHelper::showInProgressDailog);
     connect(FileEncryptHandle::instance(), &FileEncryptHandle::signalReadOutput, this, &VaultHelper::showInProgressDailog);
+
+    fmDebug() << "Vault: VaultHelper initialization completed";
 }
