@@ -6,6 +6,7 @@
 #define VAULTACTIVEFINISHEDVIEW_H
 
 #include "dfmplugin_vault_global.h"
+#include "vaultbaseview.h"
 
 #include <dtkwidget_global.h>
 #include <DSuggestButton>
@@ -23,7 +24,7 @@ class DLabel;
 DWIDGET_END_NAMESPACE
 
 namespace dfmplugin_vault {
-class VaultActiveFinishedView : public QWidget
+class VaultActiveFinishedView : public VaultBaseView
 {
     Q_OBJECT
 public:
@@ -31,12 +32,12 @@ public:
 
     void setFinishedBtnEnabled(bool b);
 
-signals:
-    void sigAccepted();
+Q_SIGNALS:
+    void reqEncryptVault();
 
 public slots:
-    //! 连接创建保险箱返回信号
-    void slotEncryptComplete(int nState);
+    void encryptFinished(bool success, const QString &msg);
+    void setProgressValue(int value);
 
 private slots:
     void slotEncryptVault();
@@ -66,9 +67,6 @@ private:
     DTK_WIDGET_NAMESPACE::DSuggestButton *finishedBtn { nullptr };
 
     QVBoxLayout *vLayout { nullptr };
-
-    //! 辅助进度条，实现加密过程效果
-    QTimer *timer { nullptr };
 };
 }
 #endif   // VAULTACTIVEFINISHEDVIEW_H
