@@ -41,6 +41,8 @@ VaultActiveSetUnlockMethodView::~VaultActiveSetUnlockMethodView()
 
 void VaultActiveSetUnlockMethodView::initUi()
 {
+    fmDebug() << "Vault: Initializing UI components";
+
     titleLabel = new DLabel(tr("Set Vault Password"), this);
     titleLabel->setAlignment(Qt::AlignHCenter);
 
@@ -123,19 +125,25 @@ void VaultActiveSetUnlockMethodView::initUi()
     AddATTag(qobject_cast<QWidget *>(transEncryptionText), AcName::kAcLabelVaultSetUnlockText);
     AddATTag(qobject_cast<QWidget *>(nextBtn), AcName::kAcBtnVaultSetUnlockNext);
 #endif
+
+    fmDebug() << "Vault: UI initialization completed successfully";
 }
 
 void VaultActiveSetUnlockMethodView::initUiForSizeMode()
 {
 #ifdef DTKWIDGET_CLASS_DSizeMode
     DFontSizeManager::instance()->bind(titleLabel, DSizeModeHelper::element(DFontSizeManager::SizeType::T7, DFontSizeManager::SizeType::T5), QFont::Medium);
+    fmDebug() << "Vault: Font size manager bound with DSizeMode support";
 #else
     DFontSizeManager::instance()->bind(titleLabel, DFontSizeManager::SizeType::T5, QFont::Medium);
+    fmDebug() << "Vault: Font size manager bound without DSizeMode support";
 #endif
 }
 
 void VaultActiveSetUnlockMethodView::initConnect()
 {
+    fmDebug() << "Vault: Initializing signal connections";
+
     connect(typeCombo, SIGNAL(currentIndexChanged(int)),
             this, SLOT(slotTypeChanged(int)));
     connect(passwordEdit, &DPasswordEdit::textEdited,
@@ -159,9 +167,12 @@ void VaultActiveSetUnlockMethodView::initConnect()
 
 #ifdef DTKWIDGET_CLASS_DSizeMode
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, [this]() {
+        fmDebug() << "Vault: Size mode changed, reinitializing UI";
         initUiForSizeMode();
     });
 #endif
+
+    fmInfo() << "Vault: All signal connections established successfully";
 }
 
 void VaultActiveSetUnlockMethodView::clearText()
@@ -183,6 +194,8 @@ void VaultActiveSetUnlockMethodView::setEncryptInfo(EncryptInfo &info)
     if (info.mode == EncryptMode::kKeyMode) {
         info.password = passwordEdit->text();
         info.hint = tipsEdit->text();
+    } else {
+        fmDebug() << "Vault: Transparent mode - no password/hint needed";
     }
 }
 
@@ -201,12 +214,14 @@ void VaultActiveSetUnlockMethodView::slotPasswordEditFinished()
 {
     bool ok = checkPassword(passwordEdit->text());
     if (!ok) {
+        fmWarning() << "Vault: Password validation failed on edit finish";
         nextBtn->setEnabled(false);
         //! 修复BUG-51508 激活密码框警告状态
         passwordEdit->setAlert(true);
         passwordEdit->showAlertMessage(tr("≥ 8 chars, contains A-Z, a-z, 0-9, and symbols"), TIPS_TIME);
     } else {
         if (checkInputInfo()) {
+            fmDebug() << "Vault: All input validated, enabling next button";
             nextBtn->setEnabled(true);
         }
     }
@@ -225,9 +240,12 @@ void VaultActiveSetUnlockMethodView::slotRepeatPasswordEditFinished()
 {
     bool ok = checkRepeatPassword();
     if (!ok) {
+        fmWarning() << "Vault: Password mismatch detected";
         //! 修复BUG-51508 激活密码框警告状态
         repeatPasswordEdit->setAlert(true);
         repeatPasswordEdit->showAlertMessage(tr("Passwords do not match"), TIPS_TIME);
+    } else {
+        fmDebug() << "Vault: Password match confirmed";
     }
 }
 
@@ -238,11 +256,13 @@ void VaultActiveSetUnlockMethodView::slotRepeatPasswordEditing()
 
     bool bSizeMatch = strRepeatPassword.size() == strPassword.size();
     if (bSizeMatch) {
+        fmDebug() << "Vault: Password lengths match, checking validation";
         if (checkPassword(passwordEdit->text())) {
             if (checkRepeatPassword()) {
                 nextBtn->setEnabled(true);
                 return;
             } else {
+                fmDebug() << "Vault: Passwords don't match, showing alert";
                 repeatPasswordEdit->showAlertMessage(tr("Passwords do not match"));
             }
         }
@@ -262,8 +282,10 @@ void VaultActiveSetUnlockMethodView::slotRepeatPasswordEditFocusChanged(bool bFo
 void VaultActiveSetUnlockMethodView::slotGenerateEditChanged(const QString &str)
 {
     if (!checkPassword(str)) {
+        fmDebug() << "Vault: Generated password validation failed";
         nextBtn->setEnabled(false);
     } else {
+        fmDebug() << "Vault: Generated password valid, enabling next button";
         nextBtn->setEnabled(true);
     }
 }
@@ -271,6 +293,8 @@ void VaultActiveSetUnlockMethodView::slotGenerateEditChanged(const QString &str)
 void VaultActiveSetUnlockMethodView::slotTypeChanged(int index)
 {
     if (index) {   // transparent encrypyion
+        fmDebug() << "Vault: Switching to transparent encryption mode";
+
         gridLayout->removeWidget(passwordLabel);
         gridLayout->removeWidget(passwordEdit);
         gridLayout->removeWidget(repeatPasswordLabel);
@@ -290,6 +314,8 @@ void VaultActiveSetUnlockMethodView::slotTypeChanged(int index)
 
         nextBtn->setEnabled(true);
     } else {   // key encryption
+        fmDebug() << "Vault: Switching to key encryption mode";
+
         gridLayout->removeItem(transEncryptTextLay);
         transEncryptionText->setVisible(false);
 
@@ -315,7 +341,9 @@ void VaultActiveSetUnlockMethodView::slotLimiPasswordLength(const QString &passw
 {
     DPasswordEdit *pPasswordEdit = qobject_cast<DPasswordEdit *>(sender());
     if (password.length() > PASSWORD_LENGHT_MAX) {
-        pPasswordEdit->setText(password.mid(0, PASSWORD_LENGHT_MAX));
+        QString truncated = password.mid(0, PASSWORD_LENGHT_MAX);
+        pPasswordEdit->setText(truncated);
+        fmWarning() << "Vault: Password truncated from" << password.length() << "to" << PASSWORD_LENGHT_MAX << "characters";
     }
 }
 
@@ -329,8 +357,8 @@ bool VaultActiveSetUnlockMethodView::checkPassword(const QString &password)
     QValidator::State res;
     res = v.validate(strPassword, pos);
     if (QValidator::Acceptable != res) {
+        fmDebug() << "Vault: Password failed validation - insufficient complexity or length";
         return false;
-
     } else {
         return true;
     }
@@ -341,6 +369,7 @@ bool VaultActiveSetUnlockMethodView::checkRepeatPassword()
     const QString &strRepeatPassword = repeatPasswordEdit->text();
     const QString &strPassword = passwordEdit->text();
     if (strRepeatPassword != strPassword) {
+        fmDebug() << "Vault: Passwords do not match";
         return false;
     } else {
         return true;
