@@ -29,7 +29,7 @@ RootInfo::RootInfo(const QUrl &u, const bool canCache, QObject *parent)
 
     // 使用关键字提取器来处理关键字解析
     keyWords = KeywordExtractorManager::instance().extractor().extractFromUrl(url);
-    
+
     if (!keyWords.isEmpty()) {
         fmDebug() << "Extracted keywords for search:" << keyWords;
     }
@@ -40,6 +40,7 @@ RootInfo::RootInfo(const QUrl &u, const bool canCache, QObject *parent)
 
 RootInfo::~RootInfo()
 {
+    isDying.store(true);
     fmInfo() << "RootInfo destructor started for URL:" << url.toString();
 
     disconnect();
@@ -331,10 +332,14 @@ void RootInfo::doFileUpdated(const QUrl &url)
 
 void RootInfo::doWatcherEvent()
 {
-    if (processFileEventRuning)
-        return;
+    // 使用原子性的 test_and_set 操作
+    bool expected = false;
+    // 如果 processFileEventRuning 是 false，则将其设置为 true，并返回 true
+    // 如果已经是 true，则什么都不做，并返回 false
+    if (!processFileEventRuning.compare_exchange_strong(expected, true)) {
+        return;   // 已经有其他线程在运行，直接返回
+    }
 
-    processFileEventRuning = true;
     QElapsedTimer timer;
     timer.start();
     QList<QUrl> adds, updates, removes;
@@ -422,7 +427,7 @@ void RootInfo::doWatcherEvent()
             removes.append(fileUrl);
         }
     }
-    processFileEventRuning = false;
+    processFileEventRuning.store(false);   // 运行完毕，重置标志
 
     // 处理添加文件
     if (!removes.isEmpty())
@@ -435,7 +440,7 @@ void RootInfo::doWatcherEvent()
 
 void RootInfo::doThreadWatcherEvent()
 {
-    if (processFileEventRuning)
+    if (isDying.load() || processFileEventRuning)
         return;
     for (auto it = watcherEventFutures.begin(); it != watcherEventFutures.end();) {
         if (it->isFinished()) {
@@ -446,7 +451,7 @@ void RootInfo::doThreadWatcherEvent()
     }
 
     watcherEventFutures << QtConcurrent::run([&]() {
-        if (cancelWatcherEvent)
+        if (cancelWatcherEvent || isDying.load())
             return;
         doWatcherEvent();
     });
@@ -655,7 +660,6 @@ SortInfoPointer RootInfo::sortFileInfo(const FileInfoPointer &info)
     sortInfo->setLastReadTime(info->timeOf(TimeInfoType::kLastRead).value<QDateTime>().toSecsSinceEpoch());
     sortInfo->setLastModifiedTime(info->timeOf(TimeInfoType::kLastModified).value<QDateTime>().toSecsSinceEpoch());
     sortInfo->setCreateTime(info->timeOf(TimeInfoType::kCreateTime).value<QDateTime>().toSecsSinceEpoch());
-    sortInfo->setDisplayType(info->displayOf(DisPlayInfoType::kMimeTypeDisplayName));
     sortInfo->setInfoCompleted(true);
     return sortInfo;
 }
