@@ -13,6 +13,8 @@
 #include <dfm-base/base/standardpaths.h>
 #include <dfm-base/utils/universalutils.h>
 #include <dfm-base/mimetype/mimetypedisplaymanager.h>
+#include <dfm-base/utils/sortutils.h>
+#include <dfm-base/utils/protocolutils.h>
 
 #include <dfm-io/dfmio_utils.h>
 
@@ -82,21 +84,24 @@ FileSortWorker::~FileSortWorker()
 
 FileSortWorker::SortOpt FileSortWorker::setSortAgruments(const Qt::SortOrder order, const Global::ItemRoles sortRole, const bool isMixDirAndFile)
 {
+    // 强制树形模式下 isMixDirAndFile 为 false
+    bool mixDirAndFile = istree ? false : isMixDirAndFile;
+
     FileSortWorker::SortOpt opt { FileSortWorker::SortOpt::kSortOptNone };
-    if (sortOrder == order && orgSortRole == sortRole && this->isMixDirAndFile == isMixDirAndFile)
+    if (sortOrder == order && orgSortRole == sortRole && this->isMixDirAndFile == mixDirAndFile)
         return opt;
-    if (orgSortRole != sortRole || this->isMixDirAndFile != isMixDirAndFile) {
+    if (orgSortRole != sortRole || this->isMixDirAndFile != mixDirAndFile) {
         opt = FileSortWorker::SortOpt::kSortOptOtherChanged;
     } else {
         opt = FileSortWorker::SortOpt::kSortOptOnlyOrderChanged;
     }
 
     fmInfo() << "Setting sort arguments - order:" << (order == Qt::AscendingOrder ? "Ascending" : "Descending")
-             << "role:" << static_cast<int>(sortRole) << "mix dir and file:" << isMixDirAndFile;
+             << "role:" << static_cast<int>(sortRole) << "mix dir and file:" << mixDirAndFile;
 
     sortOrder = order;
     orgSortRole = sortRole;
-    this->isMixDirAndFile = isMixDirAndFile;
+    this->isMixDirAndFile = mixDirAndFile;
     switch (sortRole) {
     case Global::ItemRoles::kItemFileDisplayNameRole:
         this->sortRole = DEnumerator::SortRoleCompareFlag::kSortRoleCompareFileName;
@@ -382,7 +387,7 @@ void FileSortWorker::handleWatcherAddChildren(const QList<SortInfoPointer> &chil
             return;
         }
 
-        if (this->children.value(parantUrl(sortInfo->fileUrl())).contains(sortInfo->fileUrl())) {
+        if (this->children.value(makeParentUrl(sortInfo->fileUrl())).contains(sortInfo->fileUrl())) {
             auto data = childData(sortInfo->fileUrl());
             if (data && data->fileInfo())
                 data->fileInfo()->updateAttributes();
@@ -407,7 +412,7 @@ void FileSortWorker::handleWatcherRemoveChildren(const QList<SortInfoPointer> &c
 
     fmDebug() << "Handling watcher remove children - count:" << children.size();
 
-    auto parentUrl = parantUrl(children.first()->fileUrl());
+    auto parentUrl = makeParentUrl(children.first()->fileUrl());
 
     for (const auto &sortInfo : children) {
         if (isCanceled) {
@@ -472,7 +477,7 @@ bool FileSortWorker::handleWatcherUpdateFile(const SortInfoPointer child)
     if (!child)
         return false;
 
-    if (!child->fileUrl().isValid() || !this->children.value(parantUrl(child->fileUrl())).contains(child->fileUrl()))
+    if (!child->fileUrl().isValid() || !this->children.value(makeParentUrl(child->fileUrl())).contains(child->fileUrl()))
         return false;
 
     FileInfoPointer info;
@@ -515,7 +520,7 @@ void FileSortWorker::handleWatcherUpdateHideFile(const QUrl &hidUrl)
     if (!hiddenFileInfo)
         return;
     auto hidlist = DFMUtils::hideListFromUrl(QUrl::fromLocalFile(hiddenFileInfo->pathOf(PathInfoType::kFilePath)));
-    auto parentUrl = parantUrl(hidUrl);
+    auto parentUrl = makeParentUrl(hidUrl);
     for (const auto &child : children.value(parentUrl)) {
         if (isCanceled)
             return;
@@ -585,7 +590,7 @@ bool FileSortWorker::handleUpdateFile(const QUrl &url)
     if (!url.isValid())
         return false;
 
-    SortInfoPointer sortInfo = children.value(parantUrl(url)).value(url);
+    SortInfoPointer sortInfo = children.value(makeParentUrl(url)).value(url);
     if (!sortInfo)
         return false;
 
@@ -613,7 +618,7 @@ bool FileSortWorker::handleUpdateFile(const QUrl &url)
 
     bool added = false;
     if (checkFilters(sortInfo, true)) {
-        auto parentUrl = parantUrl(sortInfo->fileUrl());
+        auto parentUrl = makeParentUrl(sortInfo->fileUrl());
         int showIndex = findStartPos(parentUrl);
 
         // 插入到每个目录下的显示目录
@@ -722,7 +727,7 @@ void FileSortWorker::handleClearThumbnail()
 void FileSortWorker::handleFileInfoUpdated(const QUrl &url, const QString &infoPtr, const bool isLinkOrg)
 {
     Q_UNUSED(isLinkOrg);
-    if (!children.value(parantUrl(url)).contains(url))
+    if (!children.value(makeParentUrl(url)).contains(url))
         return;
 
     auto itemdata = childData(url);
@@ -749,7 +754,7 @@ void FileSortWorker::handleFileInfoUpdated(const QUrl &url, const QString &infoP
         return;
 
     if (!updateRefresh) {
-        updateRefresh = new QTimer(this); // 设置parent，确保在对象销毁时自动清理
+        updateRefresh = new QTimer(this);   // 设置parent，确保在对象销毁时自动清理
         connect(updateRefresh, &QTimer::timeout, this, &FileSortWorker::handleUpdateRefreshFiles, Qt::QueuedConnection);
     }
     updateRefresh->setSingleShot(true);
@@ -823,7 +828,7 @@ void FileSortWorker::handleAddChildren(const QString &key,
 
     // In the home, it is necessary to sort by display name.
     // So, using `sortAllFiles` to reorder
-    auto parentUrl = parantUrl(children.first()->fileUrl());
+    auto parentUrl = makeParentUrl(children.first()->fileUrl());
     bool isHome = parentUrl.path() == StandardPaths::location(StandardPaths::kHomePath);
     if (!isHome && sortRole != DEnumerator::SortRoleCompareFlag::kSortRoleCompareDefault && this->sortRole == sortRole
         && this->sortOrder == sortOrder && this->isMixDirAndFile == isMixDirAndFile) {
@@ -857,7 +862,7 @@ bool FileSortWorker::handleAddChildren(const QString &key,
         return true;
 
     // Clear old data when receiving first batch of items in kPreserve mode
-    if (isFirstBatch) {
+    if (isFirstBatch && !istree) {
         visibleTreeChildren.clear();
         // Clear the existing children data when we're about to insert the first batch
         QWriteLocker lk(&childrenDataLocker);
@@ -873,7 +878,7 @@ bool FileSortWorker::handleAddChildren(const QString &key,
     QList<QUrl> newChildren;
     childrenDataLastMap.clear();
 
-    auto parentUrl = parantUrl(children.first()->fileUrl());
+    auto parentUrl = makeParentUrl(children.first()->fileUrl());
     // 获取当前的插入的位置
     auto childUrls = visibleTreeChildren.take(parentUrl);
     auto startPos = findStartPos(parentUrl);
@@ -1030,7 +1035,7 @@ QList<QUrl> FileSortWorker::filterFilesByParent(const QUrl &dir, const bool byIn
                 return {};
             if (!UniversalUtils::urlEquals(parent, current) && !UniversalUtils::isParentUrl(parent, dir))
                 continue;
-            auto sortInfo = children.value(parantUrl(parent)).value(parent);
+            auto sortInfo = children.value(makeParentUrl(parent)).value(parent);
             if (sortInfo && sortInfo->needsCompletion())
                 doCompleteFileInfo(sortInfo);
             if (!UniversalUtils::urlEquals(parent, current) && !checkFilters(sortInfo, byInfo)) {
@@ -1084,7 +1089,7 @@ bool FileSortWorker::addChild(const SortInfoPointer &sortInfo,
     if (isCanceled || sortInfo.isNull())
         return false;
 
-    auto parentUrl = parantUrl(sortInfo->fileUrl());
+    auto parentUrl = makeParentUrl(sortInfo->fileUrl());
     auto depth = findDepth(parentUrl);
     if (depth < 0)
         return false;
@@ -1165,7 +1170,7 @@ bool FileSortWorker::sortInfoUpdateByFileInfo(const FileInfoPointer fileInfo)
         return false;
 
     auto url = fileInfo->fileUrl();
-    auto parentUrl = parantUrl(url);
+    auto parentUrl = makeParentUrl(url);
     if (!children.value(parentUrl).contains(url))
         return false;
 
@@ -1185,7 +1190,6 @@ bool FileSortWorker::sortInfoUpdateByFileInfo(const FileInfoPointer fileInfo)
     sortInfo->setLastReadTime(fileInfo->timeOf(TimeInfoType::kLastRead).value<QDateTime>().toSecsSinceEpoch());
     sortInfo->setLastModifiedTime(fileInfo->timeOf(TimeInfoType::kLastModified).value<QDateTime>().toSecsSinceEpoch());
     sortInfo->setCreateTime(fileInfo->timeOf(TimeInfoType::kCreateTime).value<QDateTime>().toSecsSinceEpoch());
-    sortInfo->setDisplayType(fileInfo->displayOf(DisPlayInfoType::kMimeTypeDisplayName));
     fileInfo->fileMimeType();
 
     return true;
@@ -1287,7 +1291,7 @@ QList<QUrl> FileSortWorker::sortTreeFiles(const QList<QUrl> &children, const boo
     if (isCanceled || children.isEmpty())
         return {};
 
-    auto parentUrl = parantUrl(children.first());
+    auto parentUrl = makeParentUrl(children.first());
     if (orgSortRole == Global::ItemRoles::kItemDisplayRole) {
         visibleTreeChildren.insert(parentUrl, children);
         return {};
@@ -1405,13 +1409,13 @@ int FileSortWorker::findEndPos(const QUrl &dir)
     if (UniversalUtils::urlEquals(dir, current))
         return childrenCount();
 
-    const auto &parentUrl = parantUrl(dir);
+    const auto &parentUrl = makeParentUrl(dir);
     auto index = visibleTreeChildren.value(parentUrl).indexOf(dir);
     if (index < 0)
         return -1;
 
     if (index == visibleTreeChildren.value(parentUrl).length() - 1)
-        return findEndPos(parantUrl(dir));
+        return findEndPos(makeParentUrl(dir));
 
     return getChildShowIndex(visibleTreeChildren.value(parentUrl).at(index + 1));
 }
@@ -1585,32 +1589,51 @@ bool FileSortWorker::lessThan(const QUrl &left, const QUrl &right, AbstractSortF
     QVariant leftData = data(leftSortInfo, orgSortRole);
     QVariant rightData = data(rightSortInfo, orgSortRole);
 
+    // 1. 符号链接的大小需要直接获取指向的文件的信息排序
+    // 2. 类型排序必须使用 fastMimeType 保证一致性
+    bool useFileInfo = false;
+    if (!leftData.isValid() || (leftSortInfo->isSymLink() && orgSortRole == kItemFileSizeRole)) {
+        const FileInfoPointer leftInfo = leftItem && leftItem->fileInfo()
+                ? leftItem->fileInfo()
+                : InfoFactory::create<FileInfo>(left);
+        leftData = data(leftInfo, orgSortRole);
+        useFileInfo = true;
+    }
+
+    if (!rightData.isValid() || (rightSortInfo->isSymLink() && orgSortRole == kItemFileSizeRole)) {
+        const FileInfoPointer rightInfo = rightItem && rightItem->fileInfo()
+                ? rightItem->fileInfo()
+                : InfoFactory::create<FileInfo>(right);
+        rightData = data(rightInfo, orgSortRole);
+        useFileInfo = true;
+    }
+
     // When the selected sort attribute value is the same, sort by file name
     if (leftData == rightData) {
-        QString leftName = data(leftSortInfo, dfmbase::Global::kItemFileDisplayNameRole).toString();
-        QString rightName = data(rightSortInfo, dfmbase::Global::kItemFileDisplayNameRole).toString();
-        return FileUtils::compareByStringEx(leftName, rightName);
+        QString leftName = leftSortInfo->fileUrl().fileName();
+        QString rightName = rightSortInfo->fileUrl().fileName();
+        return SortUtils::compareStringForFileName(leftName, rightName);
     }
 
     switch (orgSortRole) {
     case kItemFileDisplayNameRole:
+        return SortUtils::compareStringForFileName(leftData.toString(), rightData.toString());
     case kItemFileLastModifiedRole:
+        [[fallthrough]];
     case kItemFileCreatedRole:
+        [[fallthrough]];
+    case kItemFileDeletionDate:
+        [[fallthrough]];
+    case kItemFileLastReadRole:
+        return SortUtils::compareStringForTime(leftData.toString(), rightData.toString());
     case kItemFileMimeTypeRole:
-        return FileUtils::compareByStringEx(leftData.toString(), rightData.toString());
-    case kItemFileSizeRole: {
-        // 文件夹不参与按文件大小的排序
-        qint64 sizel = isDirLeft ? -1 : leftSortInfo->fileSize();
-        qint64 sizer = isDirRight ? -1 : rightSortInfo->fileSize();
-        if (sizel == sizer) {
-            QString leftName = data(leftSortInfo, dfmbase::Global::kItemFileDisplayNameRole).toString();
-            QString rightName = data(rightSortInfo, dfmbase::Global::kItemFileDisplayNameRole).toString();
-            return FileUtils::compareByStringEx(leftName, rightName);
-        }
-        return sizel < sizer;
-    }
+        return SortUtils::compareStringForMimeType(leftData.toString(), rightData.toString());
+    case kItemFileSizeRole:
+        // 这里的 useFileInfo 指的是使用 FileInfo 得到的 size 的数据，而非使用 sortFileInfo
+        return useFileInfo ? SortUtils::compareForSize(leftData.toLongLong(), rightData.toLongLong())
+                           : SortUtils::compareForSize(leftSortInfo, rightSortInfo);
     default:
-        return FileUtils::compareByStringEx(leftData.toString(), rightData.toString());
+        return SortUtils::compareStringForFileName(leftData.toString(), rightData.toString());
     }
 }
 
@@ -1637,7 +1660,7 @@ QVariant FileSortWorker::data(const FileInfoPointer &info, ItemRoles role)
     case kItemIconRole:
         return info->fileIcon();
     case kItemFileSizeRole:
-        return info->displayOf(DisPlayInfoType::kSizeDisplayName);
+        return info->size();
     case kItemFileMimeTypeRole:
         return info->displayOf(DisPlayInfoType::kFileTypeDisplayName);
     case kItemNameRole:
@@ -1667,7 +1690,18 @@ QVariant FileSortWorker::data(const FileInfoPointer &info, ItemRoles role)
 
 QVariant FileSortWorker::data(const SortInfoPointer &info, Global::ItemRoles role)
 {
-    if (info.isNull())
+    auto isContainInHomeDir = [info, role]() {
+        if (!info->isDir() || role != kItemFileDisplayNameRole)
+            return false;
+        const QUrl &url = info->fileUrl();
+        static const QString kHomePath = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+        const auto &path = QDir::cleanPath(url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toLocalFile());
+        return path == kHomePath;
+    };
+
+    // 1. 非本地文件的搜索结果不会进行sortinfo的填充，因此直接返回
+    // 2. Home 目录下由于 XDG 目录进行了转译，使用 fileinfo 的 displayname 更
+    if (info.isNull() || !info->fileUrl().isLocalFile() || isContainInHomeDir())
         return QVariant();
 
     switch (role) {
@@ -1685,8 +1719,24 @@ QVariant FileSortWorker::data(const SortInfoPointer &info, Global::ItemRoles rol
     }
     case kItemFileDisplayNameRole:
         return info->fileUrl().fileName();
-    case kItemFileMimeTypeRole:
-        return info->displayType();
+    case kItemFileMimeTypeRole: {
+        // perf: MIME type detection cost is high, use caching to reduce calls
+        // Avoid large-scale IO operations in CPU-intensive tasks affecting performance
+        if (info->customData("fast_mime_type").isValid()) {
+            return info->customData("fast_mime_type");
+        }
+        QString type;
+        if (ProtocolUtils::isRemoteFile(info->fileUrl())) {
+            // For remote files, use fast extension-based detection
+            type = SortUtils::fastMimeType(info->fileUrl());
+        } else {
+            // For local files, use accurate content-based detection for proper sorting
+            type = SortUtils::accurateLocalMimeType(info->fileUrl());
+        }
+
+        const_cast<SortInfoPointer &>(info)->setCustomData("fast_mime_type", type);
+        return type;
+    }
     case kItemFileSizeRole:
         return info->fileSize();
     default:
@@ -1810,20 +1860,21 @@ bool FileSortWorker::isDefaultHiddenFile(const QUrl &fileUrl)
             auto blkInfo = DevProxyMng->queryBlockInfo(blk);
             const QStringList &mountPoints = blkInfo.value(DeviceProperty::kMountPoints).toStringList();
             for (const auto &mpt : mountPoints) {
-                defaultHiddenUrls.push_back(QUrl::fromLocalFile(mpt + (mpt == "/" ? "root" : "/root")));
-                defaultHiddenUrls.push_back(QUrl::fromLocalFile(mpt + (mpt == "/" ? "lost+found" : "/lost+found")));
+                defaultHiddenUrls.push_backByLock(QUrl::fromLocalFile(mpt + (mpt == "/" ? "root" : "/root")));
+                defaultHiddenUrls.push_backByLock(QUrl::fromLocalFile(mpt + (mpt == "/" ? "lost+found" : "/lost+found")));
             }
         }
     });
-    return defaultHiddenUrls.contains(fileUrl);
+    return defaultHiddenUrls.containsByLock(fileUrl);
 }
 
-QUrl FileSortWorker::parantUrl(const QUrl &url)
+QUrl FileSortWorker::makeParentUrl(const QUrl &url)
 {
-    if (!currentSupportTreeView)
+    if (!currentSupportTreeView || !istree)
         return current;
-    auto parent = UrlRoute::urlParent(url);
-    if (UniversalUtils::urlEquals(current, parent) || UniversalUtils::isParentUrl(current, parent)
+
+    auto parent = url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash);
+    if (UniversalUtils::urlEquals(current, parent) || UniversalUtils::isParentUrl(parent, current)
         || !childData(parent).isNull())
         return parent;
 
@@ -1970,9 +2021,6 @@ void FileSortWorker::doCompleteFileInfo(SortInfoPointer sortInfo)
     sortInfo->setLastModifiedTime(statBuffer.st_mtime);
     sortInfo->setCreateTime(statBuffer.st_ctime);
 
-    // 设置 MIME 类型显示名称（这个不需要额外的文件系统调用）
-    sortInfo->setDisplayType(MimeTypeDisplayManager::instance()->displayTypeFromPath(url.path()));
-
     // 标记所有信息已完成
     sortInfo->setInfoCompleted(true);
 }
