@@ -147,7 +147,6 @@ void TraversalDirThreadManager::run()
         const QList<SortInfoPointer> &fileList = iteratorAll();
         count = fileList.count();
         fmInfo() << "local dir query end, file count: " << count << " url: " << dirUrl << " elapsed: " << timer.elapsed();
-        createFileInfo(fileList);
     } else {
         count = iteratorOneByOne(timer);
         fmInfo() << "dir query end, file count: " << count << " url: " << dirUrl << " elapsed: " << timer.elapsed();
@@ -174,10 +173,7 @@ int TraversalDirThreadManager::iteratorOneByOne(const QElapsedTimer &timere)
     if (!future)
         Q_EMIT iteratorInitFinished();
 
-    if (!timer)
-        timer = new QElapsedTimer();
-
-    timer->restart();
+    timer.restart();
 
     QList<FileInfoPointer> childrenList;   // 当前遍历出来的所有文件
     QSet<QUrl> urls;
@@ -212,9 +208,9 @@ int TraversalDirThreadManager::iteratorOneByOne(const QElapsedTimer &timere)
         childrenList.append(fileInfo);
         filecount++;
 
-        if (timer->elapsed() > timeCeiling || childrenList.count() > countCeiling) {
+        if (timer.elapsed() > timeCeiling || childrenList.count() > countCeiling) {
             emit updateChildrenManager(childrenList, traversalToken);
-            timer->restart();
+            timer.restart();
             childrenList.clear();
         }
     }
@@ -272,13 +268,3 @@ QList<SortInfoPointer> TraversalDirThreadManager::iteratorAll()
 
     return fileList;
 }
-
-void TraversalDirThreadManager::createFileInfo(const QList<SortInfoPointer> &list)
-{
-    for (const SortInfoPointer &sortInfo : list) {
-        if (stopFlag)
-            return;
-        const QUrl &url = sortInfo->fileUrl();
-        InfoFactory::create<FileInfo>(url);
-    }
-}
