@@ -221,6 +221,7 @@ bool FileView::setRootUrl(const QUrl &url)
     d->statusBar->itemCounted(0);
 
     const QUrl &fileUrl = parseSelectedUrl(url);
+
     const QModelIndex &index = model()->setRootUrl(fileUrl);
     d->itemsExpandable = DConfigManager::instance()->value(kViewDConfName, kTreeViewEnable, true).toBool()
             && WorkspaceHelper::instance()->isViewModeSupported(rootUrl().scheme(), DFMGLOBAL_NAMESPACE::ViewMode::kTreeMode);
@@ -1508,11 +1509,8 @@ void FileView::mousePressEvent(QMouseEvent *event)
         } else if (WindowUtils::keyCtrlIsPressed() && selectionModel()->isSelected(index)) {
             d->selectHelper->setSelection(selectionModel()->selection());
             d->lastMousePressedIndex = index;
-
             DListView::mousePressEvent(event);
 
-            selectionModel()->select(index, QItemSelectionModel::Select);
-
             return;
         } else if (WindowUtils::keyShiftIsPressed()) {
             if (!selectionModel()->isSelected(index)) {   // 如果该项没有被选择
@@ -1829,9 +1827,7 @@ void FileView::contextMenuEvent(QContextMenuEvent *event)
 
             selectionModel()->select(index, QItemSelectionModel::Select);
         }
-        auto info = model()->fileInfo(index);
-        if (info)
-            info->updateAttributes();
+
         d->viewMenuHelper->showNormalMenu(index, model()->flags(index));
     }
 }
@@ -2026,6 +2022,10 @@ bool FileView::eventFilter(QObject *obj, QEvent *event)
         break;
     }
 
+    if (obj == d->headerWidget && event->type() == QEvent::Resize) {
+        d->headerView->adjustSize();
+    }
+
     return DListView::eventFilter(obj, event);
 }
 
